pub fn source(res: &SourceResult) -> StringExpand description
grove source — the symbol’s source body. The CLI’s “also matched” hint goes
to stderr, so it is not part of captured stdout and not rendered here.
pub fn source(res: &SourceResult) -> Stringgrove source — the symbol’s source body. The CLI’s “also matched” hint goes
to stderr, so it is not part of captured stdout and not rendered here.